#[repr(transparent)]pub struct Pmcfg(pub u32);Expand description
Pattern-Match Interrupt Bit Slice Configuration
Tuple Fields
0: u32Implementations
Sourceimpl Pmcfg
impl Pmcfg
Sourcepub const fn prod_endpts0(&self) -> ProdEndpts0
pub const fn prod_endpts0(&self) -> ProdEndpts0
Determines whether slice 0 is an endpoint. Slice 0 is not an endpoint. Slice 0 is the endpoint of a product term (minterm). Pin interrupt 0 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn set_prod_endpts0(&mut self, val: ProdEndpts0)
pub const fn set_prod_endpts0(&mut self, val: ProdEndpts0)
Determines whether slice 0 is an endpoint. Slice 0 is not an endpoint. Slice 0 is the endpoint of a product term (minterm). Pin interrupt 0 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn prod_endpts1(&self) -> ProdEndpts1
pub const fn prod_endpts1(&self) -> ProdEndpts1
Determines whether slice 1 is an endpoint. Slice 1 is not an endpoint. Slice 1 is the endpoint of a product term (minterm). Pin interrupt 1 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn set_prod_endpts1(&mut self, val: ProdEndpts1)
pub const fn set_prod_endpts1(&mut self, val: ProdEndpts1)
Determines whether slice 1 is an endpoint. Slice 1 is not an endpoint. Slice 1 is the endpoint of a product term (minterm). Pin interrupt 1 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn prod_endpts2(&self) -> ProdEndpts2
pub const fn prod_endpts2(&self) -> ProdEndpts2
Determines whether slice 2 is an endpoint. Slice 2 is not an endpoint. Slice 2 is the endpoint of a product term (minterm). Pin interrupt 2 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn set_prod_endpts2(&mut self, val: ProdEndpts2)
pub const fn set_prod_endpts2(&mut self, val: ProdEndpts2)
Determines whether slice 2 is an endpoint. Slice 2 is not an endpoint. Slice 2 is the endpoint of a product term (minterm). Pin interrupt 2 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn prod_endpts3(&self) -> ProdEndpts3
pub const fn prod_endpts3(&self) -> ProdEndpts3
Determines whether slice 3 is an endpoint. Slice 3 is not an endpoint. Slice 3 is the endpoint of a product term (minterm). Pin interrupt 3 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn set_prod_endpts3(&mut self, val: ProdEndpts3)
pub const fn set_prod_endpts3(&mut self, val: ProdEndpts3)
Determines whether slice 3 is an endpoint. Slice 3 is not an endpoint. Slice 3 is the endpoint of a product term (minterm). Pin interrupt 3 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn prod_endpts4(&self) -> ProdEndpts4
pub const fn prod_endpts4(&self) -> ProdEndpts4
Determines whether slice 4 is an endpoint. Slice 4 is not an endpoint. Slice 4 is the endpoint of a product term (minterm). Pin interrupt 4 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn set_prod_endpts4(&mut self, val: ProdEndpts4)
pub const fn set_prod_endpts4(&mut self, val: ProdEndpts4)
Determines whether slice 4 is an endpoint. Slice 4 is not an endpoint. Slice 4 is the endpoint of a product term (minterm). Pin interrupt 4 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn prod_endpts5(&self) -> ProdEndpts5
pub const fn prod_endpts5(&self) -> ProdEndpts5
Determines whether slice 5 is an endpoint. Slice 5 is not an endpoint. Slice 5 is the endpoint of a product term (minterm). Pin interrupt 5 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn set_prod_endpts5(&mut self, val: ProdEndpts5)
pub const fn set_prod_endpts5(&mut self, val: ProdEndpts5)
Determines whether slice 5 is an endpoint. Slice 5 is not an endpoint. Slice 5 is the endpoint of a product term (minterm). Pin interrupt 5 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn prod_endpts6(&self) -> ProdEndpts6
pub const fn prod_endpts6(&self) -> ProdEndpts6
Determines whether slice 6 is an endpoint. Slice 6 is not an endpoint. Slice 6 is the endpoint of a product term (minterm). Pin interrupt 6 in the NVIC is raised if the minterm evaluates as true.
Sourcepub const fn set_prod_endpts6(&mut self, val: ProdEndpts6)
pub const fn set_prod_endpts6(&mut self, val: ProdEndpts6)
Determines whether slice 6 is an endpoint. Slice 6 is not an endpoint. Slice 6 is the endpoint of a product term (minterm). Pin interrupt 6 in the NVIC is raised if the minterm evaluates as true.