#[repr(transparent)]pub struct Pmctrl(pub u32);Expand description
Pattern-Match Interrupt Control
Tuple Fields
0: u32Implementations
Sourceimpl Pmctrl
impl Pmctrl
Sourcepub const fn sel_pmatch(&self) -> SelPmatch
pub const fn sel_pmatch(&self) -> SelPmatch
Specifies whether the pin interrupts are controlled by the pin interrupt function or by the pattern-match function. If this value is 0b, interrupts are driven in response to the standard pin interrupt function. If this value is 1b, interrupts are driven in response to pattern matches.
Sourcepub const fn set_sel_pmatch(&mut self, val: SelPmatch)
pub const fn set_sel_pmatch(&mut self, val: SelPmatch)
Specifies whether the pin interrupts are controlled by the pin interrupt function or by the pattern-match function. If this value is 0b, interrupts are driven in response to the standard pin interrupt function. If this value is 1b, interrupts are driven in response to pattern matches.
Sourcepub const fn ena_rxev(&self) -> bool
pub const fn ena_rxev(&self) -> bool
Enables the RXEV output to the CPU and/or to a GPIO output, when the specified Boolean expression evaluates to true. If this value is 0b, RXEV output to the CPU is disabled. If this value is 1b, RXEV output to the CPU is enabled.
Sourcepub const fn set_ena_rxev(&mut self, val: bool)
pub const fn set_ena_rxev(&mut self, val: bool)
Enables the RXEV output to the CPU and/or to a GPIO output, when the specified Boolean expression evaluates to true. If this value is 0b, RXEV output to the CPU is disabled. If this value is 1b, RXEV output to the CPU is enabled.